@@ -3,9 +3,10 @@
 from .bots import *
 from .cache import *
 from .chat import *
+from .config import *
 from .errors import *
 from .memory import *
-from .run import *
+from .runner import *
 from .structs import *
 from .turbo import *
 from .types import *
@@ -23,10 +24,12 @@ __all__ = [
     "GeneratorAlreadyExhaustedError",
     "TurboGen",
     "MessageRole",
-    "PrefixMessage",
-    "BasePrefixMessageCollection",
+    "Message",
+    "BaseMessageCollection",
     "BaseMemory",
     "LocalMemory",
+    "LocalSummarizeMemory",
+    "LocalTruncatedMemory",
     "Example",
     "BaseCache",
     "SimpleCache",
@@ -35,5 +38,10 @@ __all__ = [
     "Tool",
     "turbo",
     "run",
+    "summarize_bot",
+    "subqueries_bot",
     "tool_bot",
+    "self_ask_bot",
+    "qa_bot",
+    "available_models",
 ]
