@@ -2,7 +2,6 @@
 # This is so ruff doesn't remove * imports
 
 from .cache import *
-from .config import *
 from .generators import *
 from .memory import *
 from .messages import *
@@ -10,11 +9,10 @@ from .tools import Tool
 
 __all__ = [
     "MessageRole",
-    "PrefixMessage",
+    "Message",
     "MessageDict",
-    "BasePrefixMessageCollection",
+    "BaseMessageCollection",
     "TurboGen",
-    "TurboModel",
     "BaseMemory",
     "BaseCache",
     "Tool",
